from setuptools import setup, find_packages

setup(
    name='auto_ann',
    version='0.1.3',
    url='https://github.com/essamsleiman/Auto_Annotate',
    author='Essam Sleiman',
    author_email='essamfsleiman@gmail.com',
    description='An open-source Python library designed to label your Image datasets tailored for a given task.',
    packages=find_packages(),    
    install_requires=[],
)
